ModifierCapabilityExt

Trait ModifierCapabilityExt 

pub trait ModifierCapabilityExt {
    // Required methods
    fn push_layout<N>(self, node: N) -> Self
       where N: LayoutModifierNode;
    fn push_draw<N>(self, node: N) -> Self
       where N: DrawModifierNode;
    fn push_parent_data<N>(self, node: N) -> Self
       where N: ParentDataModifierNode;
    fn push_build<N>(self, node: N) -> Self
       where N: BuildModifierNode;
    fn push_semantics<N>(self, node: N) -> Self
       where N: SemanticsModifierNode;
    fn push_pointer_preview_input<N>(self, node: N) -> Self
       where N: PointerInputModifierNode;
    fn push_pointer_input<N>(self, node: N) -> Self
       where N: PointerInputModifierNode;
    fn push_pointer_final_input<N>(self, node: N) -> Self
       where N: PointerInputModifierNode;
    fn push_keyboard_preview_input<N>(self, node: N) -> Self
       where N: KeyboardInputModifierNode;
    fn push_keyboard_input<N>(self, node: N) -> Self
       where N: KeyboardInputModifierNode;
    fn push_ime_preview_input<N>(self, node: N) -> Self
       where N: ImeInputModifierNode;
    fn push_ime_input<N>(self, node: N) -> Self
       where N: ImeInputModifierNode;
}
Low-level modifier primitive API for framework crates that build semantic modifier extensions.

This trait is intended for crates such as tessera-foundation and tessera-components that implement higher-level Modifier extensions. Most application code should prefer those semantic extensions instead of calling these methods directly.

Required Methods

fn push_layout<N>(self, node: N) -> Self

Appends a layout modifier node to the current modifier chain.

fn push_draw<N>(self, node: N) -> Self

Appends a draw modifier node to the current modifier chain.

fn push_parent_data<N>(self, node: N) -> Self

Appends a parent-data modifier node to the current modifier chain.

fn push_build<N>(self, node: N) -> Self

Appends a build modifier node to the current modifier chain.

fn push_semantics<N>(self, node: N) -> Self

Appends a semantics modifier node to the current modifier chain.

fn push_pointer_preview_input<N>(self, node: N) -> Self

Appends a preview pointer-input modifier node to the current modifier chain.

fn push_pointer_input<N>(self, node: N) -> Self

Appends a pointer-input modifier node to the current modifier chain.

fn push_pointer_final_input<N>(self, node: N) -> Self

Appends a final pointer-input modifier node to the current modifier chain.

fn push_keyboard_preview_input<N>(self, node: N) -> Self

Appends a preview keyboard-input modifier node to the current modifier chain.

fn push_keyboard_input<N>(self, node: N) -> Self

Appends a keyboard-input modifier node to the current modifier chain.

fn push_ime_preview_input<N>(self, node: N) -> Self

Appends a preview IME-input modifier node to the current modifier chain.

fn push_ime_input<N>(self, node: N) -> Self

Appends an IME-input modifier node to the current modifier chain.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors