pub trait PlacementModifierNode:
Send
+ Sync
+ 'static {
// Required method
fn transform_position(&self, position: PxPosition) -> PxPosition;
}Expand description
A node-local placement modifier that transforms the current node position without affecting measured size.
Required Methods
Sourcefn transform_position(&self, position: PxPosition) -> PxPosition
fn transform_position(&self, position: PxPosition) -> PxPosition
Returns the transformed node position relative to the parent.